parse_special

Function parse_special 

pub fn parse_special(input: &str) -> Option<SpecialCommand>
Try to parse a line of user input as a special command. Returns None if the input is a regular message.