pub fn classify_with_confidence(
agent_type: AgentType,
screen: &Screen,
) -> ClassificationExpand description
Classify screen content and return a confidence score for the match.
pub fn classify_with_confidence(
agent_type: AgentType,
screen: &Screen,
) -> ClassificationClassify screen content and return a confidence score for the match.