Module runtime

Module runtime 

The shim process: owns a PTY, runs an agent CLI, classifies state, communicates with the orchestrator via a Channel on fd 3.

Raw PTY output is also streamed to a log file so tmux display panes can tail -F it and render agent output in real time.

Structs

ShimArgs

Functions

run
Run the shim. This function does not return until the shim exits. channel is the pre-connected socket to the orchestrator (fd 3 or from a socketpair).