pub fn write_checkpoint(
project_root: &Path,
checkpoint: &Checkpoint,
) -> Result<()>Expand description
Write a progress checkpoint file for the given role.
Creates the .batty/progress/ directory if it doesn’t exist.
pub fn write_checkpoint(
project_root: &Path,
checkpoint: &Checkpoint,
) -> Result<()>Write a progress checkpoint file for the given role.
Creates the .batty/progress/ directory if it doesn’t exist.