pub struct WorkflowPolicy {Show 26 fields
pub clean_room_mode: bool,
pub barrier_groups: HashMap<String, Vec<String>>,
pub handoff_directory: String,
pub wip_limit_per_engineer: Option<u32>,
pub wip_limit_per_reviewer: Option<u32>,
pub pipeline_starvation_threshold: Option<usize>,
pub escalation_threshold_secs: u64,
pub review_nudge_threshold_secs: u64,
pub review_timeout_secs: u64,
pub review_timeout_overrides: HashMap<String, ReviewTimeoutOverride>,
pub auto_archive_done_after_secs: Option<u64>,
pub capability_overrides: HashMap<String, Vec<String>>,
pub stall_threshold_secs: u64,
pub max_stall_restarts: u32,
pub health_check_interval_secs: u64,
pub planning_cycle_cooldown_secs: u64,
pub narration_detection_threshold: usize,
pub context_pressure_threshold_bytes: u64,
pub context_pressure_restart_delay_secs: u64,
pub graceful_shutdown_timeout_secs: u64,
pub auto_commit_on_restart: bool,
pub uncommitted_warn_threshold: usize,
pub test_command: Option<String>,
pub auto_merge: AutoMergePolicy,
pub context_handoff_enabled: bool,
pub handoff_screen_history: usize,
}Fields
clean_room_mode: boolbarrier_groups: HashMap<String, Vec<String>>handoff_directory: Stringwip_limit_per_engineer: Option<u32>wip_limit_per_reviewer: Option<u32>pipeline_starvation_threshold: Option<usize>escalation_threshold_secs: u64review_nudge_threshold_secs: u64review_timeout_secs: u64review_timeout_overrides: HashMap<String, ReviewTimeoutOverride>auto_archive_done_after_secs: Option<u64>capability_overrides: HashMap<String, Vec<String>>stall_threshold_secs: u64max_stall_restarts: u32health_check_interval_secs: u64planning_cycle_cooldown_secs: u64narration_detection_threshold: usizecontext_pressure_threshold_bytes: u64context_pressure_restart_delay_secs: u64graceful_shutdown_timeout_secs: u64auto_commit_on_restart: booluncommitted_warn_threshold: usizetest_command: Option<String>auto_merge: AutoMergePolicycontext_handoff_enabled: boolWhen true, context exhaustion restarts capture a work summary and inject it into the new agent session so it can continue where the old session left off.
handoff_screen_history: usizeNumber of PTY screen pages to include in the handoff summary.