Module config_diff

Module config_diff 

Diff two team configurations to produce a topology change set.

Used by both batty scale (CLI-side) and daemon hot-reload to determine which agents need to be added, removed, or left unchanged.

Structs

MemberChange
A single member that changed between two configurations.
TopologyDiff
The result of diffing two resolved team topologies.

Functions

diff_configs
Compute the topology diff between two team configurations.
diff_members
Compute the topology diff between two resolved member lists.