pub fn diff_configs(old: &TeamConfig, new: &TeamConfig) -> Result<TopologyDiff>Expand description
Compute the topology diff between two team configurations.
Resolves both configs into member instance lists and compares by name.
pub fn diff_configs(old: &TeamConfig, new: &TeamConfig) -> Result<TopologyDiff>Compute the topology diff between two team configurations.
Resolves both configs into member instance lists and compares by name.