pub struct DiscordBot { /* private fields */ }Expand description
Blocking Discord Bot API client.
Implementations
Sourceimpl DiscordBot
impl DiscordBot
pub fn new( bot_token: String, allowed_user_ids: Vec<i64>, commands_channel_id: String, ) -> Self
Sourcepub fn from_config(config: &ChannelConfig) -> Option<Self>
pub fn from_config(config: &ChannelConfig) -> Option<Self>
Build a DiscordBot from a ChannelConfig.
Returns None if either the token or commands channel ID is missing.
The token can be provided directly or via BATTY_DISCORD_BOT_TOKEN.
pub fn commands_channel_id(&self) -> &str
pub fn send_plain_message(&self, channel_id: &str, text: &str) -> Result<()>
pub fn send_embed( &self, channel_id: &str, title: &str, description: &str, color: u32, ) -> Result<()>
pub fn send_command_reply(&self, text: &str) -> Result<()>
pub fn send_formatted_message( &self, channel_id: &str, message: &str, ) -> Result<()>
pub fn validate_token(&self) -> Result<BotIdentity>
pub fn list_guilds(&self) -> Result<Vec<GuildSummary>>
pub fn list_guild_channels(&self, guild_id: &str) -> Result<Vec<ChannelSummary>>
pub fn get_channel(&self, channel_id: &str) -> Result<ChannelSummary>
pub fn create_message(&self, channel_id: &str, body: &Value) -> Result<String>
pub fn edit_message( &self, channel_id: &str, message_id: &str, body: &Value, ) -> Result<()>
pub fn pin_message(&self, channel_id: &str, message_id: &str) -> Result<()>
pub fn poll_commands(&mut self) -> Result<Vec<InboundMessage>>