Module git_cmd

Module git_cmd 

Re-exports

pub use super::errors::GitError;

Structs

GitOutput

Functions

branch_delete
branch_rename
checkout_new_branch
discover_sub_repos
Discover immediate child directories that are git repositories. Returns an empty vec if path is itself a git repo or has no git children.
for_each_ref_branches
is_git_repo
Check whether path is inside a git work tree.
merge
merge_base_is_ancestor
rebase
rebase_abort
rev_list_count
rev_parse_branch
rev_parse_toplevel
run_git
show_ref_exists
status_porcelain
worktree_add
worktree_list
worktree_remove