Team message types and command queue management.
Enums
- Queued
Command - A message in the command queue.
Functions
- command_
queue_ path - Resolve the command queue path.
- enqueue_
command - Write a command to the queue file.
- read_
command_ queue - Read all pending commands from the queue file without clearing it.
- write_
command_ queue - Atomically rewrite the command queue with the remaining commands.