pub fn write_command_queue(
queue_path: &Path,
commands: &[QueuedCommand],
) -> Result<()>Expand description
Atomically rewrite the command queue with the remaining commands.
pub fn write_command_queue(
queue_path: &Path,
commands: &[QueuedCommand],
) -> Result<()>Atomically rewrite the command queue with the remaining commands.