Module policy

Module policy 

Functions

check_wip_limit
effective_escalation_threshold
Returns the effective escalation (review timeout) threshold for a task with the given priority. Uses per-priority override if configured, otherwise falls back to global.
effective_nudge_threshold
Returns the effective nudge threshold for a task with the given priority. Uses per-priority override if configured, otherwise falls back to global.
is_review_nudge_due
is_review_stale
should_escalate