pub fn open(project_root: &Path) -> Result<Connection>Expand description
Open or create the telemetry database, initializing the schema.
pub fn open(project_root: &Path) -> Result<Connection>Open or create the telemetry database, initializing the schema.