create_session

Function create_session 

pub fn create_session(
    session: &str,
    program: &str,
    args: &[String],
    work_dir: &str,
) -> Result<()>
Create a detached tmux session running the given command.

The session is created with new-session -d so it starts in the background. The executor command is the initial command the session runs.