paste_buffer

Function paste_buffer 

pub fn paste_buffer(target: &str) -> Result<()>
Paste the named batty buffer into a target pane and delete the buffer.

The -d flag deletes the buffer after pasting so it doesn’t linger. The -b flag selects the batty-specific buffer (never the user’s default).