pub enum OpenClawCommand {
Register {
force: bool,
},
Status {
json: bool,
},
Instruct {
role: String,
message: String,
},
Events {
project_id: Option<String>,
all_projects: bool,
json: bool,
topics: Vec<OpenClawEventTopicArg>,
roles: Vec<String>,
task_ids: Vec<String>,
event_types: Vec<String>,
session_names: Vec<String>,
since_ts: Option<u64>,
limit: Option<usize>,
include_archived: bool,
},
FollowUp {
command: OpenClawFollowUpCommand,
},
}Variants
Register
Write an OpenClaw project registration/config skeleton for Batty
Status
Show an operator-friendly Batty summary for OpenClaw supervision
Instruct
Send a high-level instruction into an allowed Batty role
Fields
Events
Export stable OpenClaw event envelopes for one project or all registered projects
Fields

project_id: Option<String>Registered project identifier; defaults to the current project if it is registered

topics: Vec<OpenClawEventTopicArg>Filter by stable public event topic
FollowUp
Run configured OpenClaw follow-up/reminder workflows
Fields

command: OpenClawFollowUpCommandTrait Implementations
Sourceimpl Debug for OpenClawCommand
impl Debug for OpenClawCommand
Sourceimpl FromArgMatches for OpenClawCommand
impl FromArgMatches for OpenClawCommand
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut<'b>(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut<'b>( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Subcommand for OpenClawCommand
impl Subcommand for OpenClawCommand
Sourcefn augment_subcommands<'b>(__clap_app: Command) -> Command
fn augment_subcommands<'b>(__clap_app: Command) -> Command
Sourcefn augment_subcommands_for_update<'b>(__clap_app: Command) -> Command
fn augment_subcommands_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourcefn has_subcommand(__clap_name: &str) -> bool
fn has_subcommand(__clap_name: &str) -> bool
Test whether
Self can parse a specific subcommandAuto Trait Implementations
impl Freeze for OpenClawCommand
impl RefUnwindSafe for OpenClawCommand
impl Send for OpenClawCommand
impl Sync for OpenClawCommand
impl Unpin for OpenClawCommand
impl UnsafeUnpin for OpenClawCommand
impl UnwindSafe for OpenClawCommand