LogEvent

Enum LogEvent 

pub enum LogEvent {
Show 25 variants TaskRead { task_id: u32, title: String, status: String, }, WorktreeCreated { task_id: u32, path: String, branch: String, }, PhaseWorktreeCreated { phase: String, path: String, branch: String, base_branch: String, }, PhaseWorktreeRetained { phase: String, path: String, branch: String, reason: String, }, PhaseWorktreeCleaned { phase: String, path: String, branch: String, }, AgentLaunched { agent: String, program: String, args: Vec<String>, work_dir: String, }, LaunchContextSnapshot { phase: String, agent: String, instructions_path: String, phase_doc_path: String, config_source: String, snapshot_path: String, snapshot: String, }, PhaseSelectionDecision { phase: String, order_key: String, selected: bool, reason: String, }, ReviewPacketGenerated { phase: String, packet_path: String, diff_command: String, summary_path: Option<String>, statements_count: usize, execution_log_path: String, }, ReviewDecision { phase: String, decision: String, feedback: Option<String>, }, ReworkCycleStarted { phase: String, attempt: u32, max_retries: u32, feedback: String, }, PromptDetected { kind: String, matched_text: String, }, AutoResponse { prompt: String, response: String, }, UserInput { length: usize, }, TestExecuted { command: String, passed: bool, exit_code: Option<i32>, }, TestResult { attempt: u32, passed: bool, output_lines: usize, }, Commit { hash: String, message: String, }, Merge { source: String, target: String, }, PolicyDecision { decision: String, prompt: String, }, AgentOutput { line: String, }, RunCompleted { summary: String, }, RunFailed { reason: String, }, CompletionDecision {
Show 13 fields phase: String, passed: bool, board_all_done: bool, milestone_done: bool, summary_exists: bool, dod_passed: bool, executor_stable: bool, reasons: Vec<String>, summary_path: Option<String>, dod_command: String, dod_executed: bool, dod_exit_code: Option<i32>, dod_output_lines: usize,
}, SessionStarted { phase: String, }, SessionEnded { result: String, },
}
All event types that can appear in the execution log.

Variants



TaskRead

A task was read from the kanban board.

Fields

task_id: u32
title: String
status: String


WorktreeCreated

A git worktree was created for the task.

Fields

task_id: u32
path: String
branch: String


PhaseWorktreeCreated

A phase run worktree was created.

Fields

phase: String
path: String
branch: String
base_branch: String


PhaseWorktreeRetained

A run worktree was retained for later inspection.

Fields

phase: String
path: String
branch: String
reason: String


PhaseWorktreeCleaned

A run worktree was cleaned up after merge.

Fields

phase: String
path: String
branch: String


AgentLaunched

An agent process was launched.

Fields

agent: String
program: String
args: Vec<String>
work_dir: String


LaunchContextSnapshot

Launch context was composed and snapshotted before execution.

Fields

phase: String
agent: String
instructions_path: String
phase_doc_path: String
config_source: String
snapshot_path: String
snapshot: String


PhaseSelectionDecision

A phase sequencing decision was recorded.

Fields

phase: String
order_key: String
selected: bool
reason: String


ReviewPacketGenerated

A standardized review packet was generated for human review.

Fields

phase: String
packet_path: String
diff_command: String
summary_path: Option<String>
statements_count: usize
execution_log_path: String


ReviewDecision

A human review decision was recorded.

Fields

phase: String
decision: String
feedback: Option<String>


ReworkCycleStarted

A rework cycle was launched after human review feedback.

Fields

phase: String
attempt: u32
max_retries: u32
feedback: String


PromptDetected

A prompt was detected in agent output.

Fields

kind: String
matched_text: String


AutoResponse

An auto-response was sent to the agent.

Fields

prompt: String
response: String


UserInput

User input was forwarded to the agent.

Fields

length: usize


TestExecuted

A DoD test command was executed.

Fields

command: String
passed: bool
exit_code: Option<i32>


TestResult

Result of a DoD test (with output summary).

Fields

attempt: u32
passed: bool
output_lines: usize


Commit

A git commit was created.

Fields

hash: String
message: String


Merge

A branch was merged.

Fields

source: String
target: String


PolicyDecision

A policy decision was made.

Fields

decision: String
prompt: String


AgentOutput

Agent output line (for verbose logging).

Fields

line: String


RunCompleted

The run completed successfully.

Fields

summary: String


RunFailed

The run failed.

Fields

reason: String


CompletionDecision

Completion contract decision (accept/reject + check results).

Fields

phase: String
passed: bool
board_all_done: bool
milestone_done: bool
summary_exists: bool
dod_passed: bool
executor_stable: bool
reasons: Vec<String>
summary_path: Option<String>
dod_command: String
dod_executed: bool
dod_exit_code: Option<i32>
dod_output_lines: usize


SessionStarted

Session started.

Fields

phase: String


SessionEnded

Session ended.

Fields

result: String