pub struct SdkOutput {
pub msg_type: String,
pub subtype: Option<String>,
pub session_id: Option<String>,
pub uuid: Option<String>,
pub message: Option<Value>,
pub event: Option<Value>,
pub result: Option<String>,
pub num_turns: Option<u32>,
pub is_error: Option<bool>,
pub errors: Option<Vec<String>>,
pub request_id: Option<String>,
pub request: Option<Value>,
}Expand description
A single NDJSON message received from Claude Code’s stdout.
Uses a flat struct with optional fields rather than a tagged enum so that unknown or new message types are silently tolerated (future-proof).
Fields
msg_type: Stringsubtype: Option<String>session_id: Option<String>uuid: Option<String>message: Option<Value>For assistant messages: the full message object with content array.
event: Option<Value>For stream_event messages: the stream event payload.
result: Option<String>For result messages: the final text result.
num_turns: Option<u32>For result messages: number of API turns taken.
is_error: Option<bool>For result messages: whether an error occurred.
errors: Option<Vec<String>>For result error messages: list of error strings.
request_id: Option<String>For control_request messages: the request ID to echo in responses.
request: Option<Value>For control_request messages: the request payload.
Implementations