WatcherState

Enum WatcherState 

pub enum WatcherState {
    Active,
    Ready,
    Idle,
    PaneDead,
    ContextExhausted,
}
State of a watched agent session.

Variants



Active

Agent is actively producing output.



Ready

Agent CLI has started and is showing its input prompt, ready for messages. Transitional state between pane creation and first Idle classification.



Idle

No agent running in pane (idle / waiting for assignment).



PaneDead

The tmux pane no longer exists or its process has exited.



ContextExhausted

Agent reported that its conversation/session is too large to continue.