sync_phase_board_to_worktree

Function sync_phase_board_to_worktree 

pub fn sync_phase_board_to_worktree(
    project_root: &Path,
    worktree_root: &Path,
    phase: &str,
) -> Result<()>
Sync the phase board from the source tree into the worktree.

Worktrees are created from committed state, so any uncommitted kanban changes (new tasks, reworked boards, etc.) would be lost. This copies the phase directory from source_kanban_root/<phase>/ into worktree_kanban_root/<phase>/, overwriting whatever git checked out.

Only syncs when the source directory exists and differs from the worktree (i.e., the source tree has uncommitted kanban changes).